// MESSAGE CAP_STATUS support class

#pragma once

namespace mavlink {
namespace common {
namespace msg {

/**
 * @brief CAP_STATUS message
 *
 * Status of the C-Astral autopilot
 */
struct CAP_STATUS : mavlink::Message {
    static constexpr msgid_t MSG_ID = 15000;
    static constexpr size_t LENGTH = 58;
    static constexpr size_t MIN_LENGTH = 58;
    static constexpr uint8_t CRC_EXTRA = 225;
    static constexpr auto NAME = "CAP_STATUS";


    uint16_t air_time; /*<  Time since take-off */
    uint32_t primary_status; /*<  1-parachute, 2-home init, 3-landed, 4-speed override, 5-altitude ovveride, 6-battery low, 7-battery critical, 8-battery emergency, 9-battery parachute pop, 10-failsafe GPS loss, 11-failsafe data link loss, 12-failsafe mission, 13-failsafe offboard loss, 14-failsafe loss of control, 15-failsafe_min_agl, 16 - reserved, 17 - terrain failsafe enabled, 18 - altitude override type, 19 - speed override type, 20 - gimbal extended, 21 - CAP lights, 22 - Position lights, 23 - IR lights, 24 - Strobo lights, 25 - underspeed, 26 - telemetry 2 control enabled, [0, 27-32]: reserved */
    uint32_t secondary_status; /*<  Reserved */
    int16_t altitude_override_value; /*<  Altutde override value */
    float speed_override_value; /*<  Speed override value */
    uint32_t flightplan_hash; /*<  Flightplan hash */
    uint16_t flightplan_items_count; /*<  Flightplan Items Count */
    float eph; /*<  Standard deviation of horizontal position error, (metres) */
    float epv; /*<  Standard deviation of vertical position error, (metres) */
    float loiter_radius; /*<  Current loiter radius */
    float time_to_home; /*<  Time to home in seconds */
    float max_distance_from_home; /*<  Max distance from home in meters */
    float reserved2; /*<  reserved2 */
    float reserved3; /*<  reserved3 */
    float reserved4; /*<  reserved4 */
    float reserved5; /*<  reserved5 */


    inline std::string get_name(void) const override
    {
            return NAME;
    }

    inline Info get_message_info(void) const override
    {
            return { MSG_ID, LENGTH, MIN_LENGTH, CRC_EXTRA };
    }

    inline std::string to_yaml(void) const override
    {
        std::stringstream ss;

        ss << NAME << ":" << std::endl;
        ss << "  air_time: " << air_time << std::endl;
        ss << "  primary_status: " << primary_status << std::endl;
        ss << "  secondary_status: " << secondary_status << std::endl;
        ss << "  altitude_override_value: " << altitude_override_value << std::endl;
        ss << "  speed_override_value: " << speed_override_value << std::endl;
        ss << "  flightplan_hash: " << flightplan_hash << std::endl;
        ss << "  flightplan_items_count: " << flightplan_items_count << std::endl;
        ss << "  eph: " << eph << std::endl;
        ss << "  epv: " << epv << std::endl;
        ss << "  loiter_radius: " << loiter_radius << std::endl;
        ss << "  time_to_home: " << time_to_home << std::endl;
        ss << "  max_distance_from_home: " << max_distance_from_home << std::endl;
        ss << "  reserved2: " << reserved2 << std::endl;
        ss << "  reserved3: " << reserved3 << std::endl;
        ss << "  reserved4: " << reserved4 << std::endl;
        ss << "  reserved5: " << reserved5 << std::endl;

        return ss.str();
    }

    inline void serialize(mavlink::MsgMap &map) const override
    {
        map.reset(MSG_ID, LENGTH);

        map << primary_status;                // offset: 0
        map << secondary_status;              // offset: 4
        map << speed_override_value;          // offset: 8
        map << flightplan_hash;               // offset: 12
        map << eph;                           // offset: 16
        map << epv;                           // offset: 20
        map << loiter_radius;                 // offset: 24
        map << time_to_home;                  // offset: 28
        map << max_distance_from_home;        // offset: 32
        map << reserved2;                     // offset: 36
        map << reserved3;                     // offset: 40
        map << reserved4;                     // offset: 44
        map << reserved5;                     // offset: 48
        map << air_time;                      // offset: 52
        map << altitude_override_value;       // offset: 54
        map << flightplan_items_count;        // offset: 56
    }

    inline void deserialize(mavlink::MsgMap &map) override
    {
        map >> primary_status;                // offset: 0
        map >> secondary_status;              // offset: 4
        map >> speed_override_value;          // offset: 8
        map >> flightplan_hash;               // offset: 12
        map >> eph;                           // offset: 16
        map >> epv;                           // offset: 20
        map >> loiter_radius;                 // offset: 24
        map >> time_to_home;                  // offset: 28
        map >> max_distance_from_home;        // offset: 32
        map >> reserved2;                     // offset: 36
        map >> reserved3;                     // offset: 40
        map >> reserved4;                     // offset: 44
        map >> reserved5;                     // offset: 48
        map >> air_time;                      // offset: 52
        map >> altitude_override_value;       // offset: 54
        map >> flightplan_items_count;        // offset: 56
    }
};

} // namespace msg
} // namespace common
} // namespace mavlink
