// MESSAGE SERIAL_PASSTHROUGH support class

#pragma once

namespace mavlink {
namespace common {
namespace msg {

/**
 * @brief SERIAL_PASSTHROUGH message
 *
 * Serial passthrough with 256 bytes payload
 */
struct SERIAL_PASSTHROUGH : mavlink::Message {
    static constexpr msgid_t MSG_ID = 15001;
    static constexpr size_t LENGTH = 133;
    static constexpr size_t MIN_LENGTH = 133;
    static constexpr uint8_t CRC_EXTRA = 9;
    static constexpr auto NAME = "SERIAL_PASSTHROUGH";


    uint8_t target_system; /*<  System which should execute the command */
    uint8_t target_component; /*<  Component which should execute the command, 0 for all components */
    uint8_t confirmation; /*<  0: First transmission of this command. 1-255: Confirmation transmissions (e.g. for kill command) */
    std::array<uint8_t, 128> data; /*<  Data */
    uint8_t size; /*<  Data size */
    uint8_t number; /*<  Message number used for acknowledge */


    inline std::string get_name(void) const override
    {
            return NAME;
    }

    inline Info get_message_info(void) const override
    {
            return { MSG_ID, LENGTH, MIN_LENGTH, CRC_EXTRA };
    }

    inline std::string to_yaml(void) const override
    {
        std::stringstream ss;

        ss << NAME << ":" << std::endl;
        ss << "  target_system: " << +target_system << std::endl;
        ss << "  target_component: " << +target_component << std::endl;
        ss << "  confirmation: " << +confirmation << std::endl;
        ss << "  data: [" << to_string(data) << "]" << std::endl;
        ss << "  size: " << +size << std::endl;
        ss << "  number: " << +number << std::endl;

        return ss.str();
    }

    inline void serialize(mavlink::MsgMap &map) const override
    {
        map.reset(MSG_ID, LENGTH);

        map << target_system;                 // offset: 0
        map << target_component;              // offset: 1
        map << confirmation;                  // offset: 2
        map << data;                          // offset: 3
        map << size;                          // offset: 131
        map << number;                        // offset: 132
    }

    inline void deserialize(mavlink::MsgMap &map) override
    {
        map >> target_system;                 // offset: 0
        map >> target_component;              // offset: 1
        map >> confirmation;                  // offset: 2
        map >> data;                          // offset: 3
        map >> size;                          // offset: 131
        map >> number;                        // offset: 132
    }
};

} // namespace msg
} // namespace common
} // namespace mavlink
