// MESSAGE SERIAL_PASSTHROUGH_ACK support class

#pragma once

namespace mavlink {
namespace common {
namespace msg {

/**
 * @brief SERIAL_PASSTHROUGH_ACK message
 *
 * Serial passthrough acknowledge
 */
struct SERIAL_PASSTHROUGH_ACK : mavlink::Message {
    static constexpr msgid_t MSG_ID = 15002;
    static constexpr size_t LENGTH = 4;
    static constexpr size_t MIN_LENGTH = 4;
    static constexpr uint8_t CRC_EXTRA = 50;
    static constexpr auto NAME = "SERIAL_PASSTHROUGH_ACK";


    uint8_t target_system; /*<  System which should execute the command */
    uint8_t target_component; /*<  Component which should execute the command, 0 for all components */
    uint8_t number; /*<  Message number to acknowledge */
    uint8_t error; /*<  Error. 0: OK, 1: Warning: unexpected message number, 10: Error: recently received - blocked */


    inline std::string get_name(void) const override
    {
            return NAME;
    }

    inline Info get_message_info(void) const override
    {
            return { MSG_ID, LENGTH, MIN_LENGTH, CRC_EXTRA };
    }

    inline std::string to_yaml(void) const override
    {
        std::stringstream ss;

        ss << NAME << ":" << std::endl;
        ss << "  target_system: " << +target_system << std::endl;
        ss << "  target_component: " << +target_component << std::endl;
        ss << "  number: " << +number << std::endl;
        ss << "  error: " << +error << std::endl;

        return ss.str();
    }

    inline void serialize(mavlink::MsgMap &map) const override
    {
        map.reset(MSG_ID, LENGTH);

        map << target_system;                 // offset: 0
        map << target_component;              // offset: 1
        map << number;                        // offset: 2
        map << error;                         // offset: 3
    }

    inline void deserialize(mavlink::MsgMap &map) override
    {
        map >> target_system;                 // offset: 0
        map >> target_component;              // offset: 1
        map >> number;                        // offset: 2
        map >> error;                         // offset: 3
    }
};

} // namespace msg
} // namespace common
} // namespace mavlink
